@@ -14,14 +14,14 @@ io utilities
 #-----------------------------------------------------------------------------
 
 import numpy as np
+from unyt import \
+    unyt_array, \
+    unyt_quantity
 
-from yt.convenience import \
-    load as _yt_load
-from yt.units.yt_array import \
-    YTArray, \
-    YTQuantity
-from yt.utilities.logger import \
-    ytLogger
+from yt.funcs import \
+    get_pbar
+from ytree.utilities.logger import \
+    fake_pbar
 
 def parse_h5_attr(f, attr):
     """A Python3-safe function for getting hdf5 attributes.
@@ -40,11 +40,11 @@ def _hdf5_yt_attr(fh, attr, unit_registry=None):
     """
     Read an hdf5 attribute.  If there exists another attribute
     named <attr>_units, use that to assign units and return
-    as either a YTArray or YTQuantity.
+    as either a unyt_array or unyt_quantity.
     """
     val = fh.attrs[attr]
     units = ""
-    ufield = "%s_units" % attr
+    ufield = f"{attr}_units"
     if ufield in fh.attrs:
         units = fh.attrs[ufield]
         if isinstance(units, bytes):
@@ -53,23 +53,24 @@ def _hdf5_yt_attr(fh, attr, unit_registry=None):
         units = ""
     if units != "":
         if isinstance(val, np.ndarray):
-            val = YTArray(val, units, registry=unit_registry)
+            val = unyt_array(val, units, registry=unit_registry)
         else:
-            val = YTQuantity(val, units, registry=unit_registry)
+            val = unyt_quantity(val, units, registry=unit_registry)
     return val
 
 def _hdf5_yt_array_lite(fh, field):
     """
     Read an hdf5 dataset.  If that dataset has a "units" attribute,
-    return that as well, but do not cast as a YTArray.
+    return that as well, but do not cast as a unyt_array.
     """
     units = ""
     if "units" in fh[field].attrs:
         units = fh[field].attrs["units"]
     if units == "dimensionless": units = ""
-    return (fh[field].value, units)
+    return (fh[field][()], units)
 
-def f_text_block(f, block_size=32768, file_size=None, sep="\n"):
+def f_text_block(f, block_size=4096, file_size=None, sep="\n",
+                 pbar_string=None):
     """
     Read lines from a file faster than f.readlines().
     """
@@ -83,6 +84,10 @@ def f_text_block(f, block_size=32768, file_size=None, sep="\n"):
                       block_size).astype(np.int64)
     read_size = file_size + start
     lbuff = ""
+    if pbar_string is None:
+        pbar = fake_pbar()
+    else:
+        pbar = get_pbar(pbar_string, file_size)
     for ib in range(nblocks):
         offset = f.tell()
         my_block = min(block_size, read_size-offset)
@@ -99,21 +104,11 @@ def f_text_block(f, block_size=32768, file_size=None, sep="\n"):
                 loc = offset - len(lbuff) + linl + 1
                 lbuff = ""
                 linl = inl
+                pbar.update(loc+len(line)-start+1)
                 yield line, loc
         lbuff += buff[linl+1:]
     if lbuff:
         loc = f.tell() - len(lbuff)
+        pbar.update(loc+len(lbuff)-start+1)
         yield lbuff, loc
-
-def yt_load(filename, **kwargs):
-    """
-    Suppress logging for yt.load, but return to original setting.
-
-    This allows yt.load to show logs in scripts, but not in ytree.
-    """
-    level = ytLogger.level
-    if level > 10 and level < 40:
-        ytLogger.setLevel(40)
-    ds = _yt_load(filename, **kwargs)
-    ytLogger.setLevel(level)
-    return ds
+    pbar.finish()
